@@ -820,18 +820,18 @@ class Sandbox:
     ) -> Template:
         """
         Get template details.
-        
+
         Args:
             name: Template name
             api_key: API key (or use HOPX_API_KEY env var)
             base_url: API base URL
-        
+
         Returns:
             Template object
-        
+
         Raises:
             NotFoundError: Template not found
-        
+
         Example:
             >>> template = Sandbox.get_template("code-interpreter")
             >>> print(template.description)
@@ -840,7 +840,77 @@ class Sandbox:
         client = HTTPClient(api_key=api_key, base_url=base_url)
         response = client.get(f"/v1/templates/{name}")
         return Template(**response)
-    
+
+    @classmethod
+    def delete_template(
+        cls,
+        template_id: str,
+        *,
+        api_key: Optional[str] = None,
+        base_url: str = "https://api.hopx.dev",
+    ) -> Dict[str, Any]:
+        """
+        Delete a custom template.
+
+        Only organization-owned templates can be deleted. Public templates cannot be deleted.
+
+        Args:
+            template_id: Template ID to delete
+            api_key: API key (or use HOPX_API_KEY env var)
+            base_url: API base URL
+
+        Returns:
+            Dict with deletion confirmation
+
+        Raises:
+            NotFoundError: Template not found
+            ValidationError: Cannot delete public templates
+            AuthenticationError: Invalid API key
+
+        Example:
+            >>> # Delete a custom template by ID
+            >>> result = Sandbox.delete_template("template_123abc")
+            >>> print(result)
+        """
+        client = HTTPClient(api_key=api_key, base_url=base_url)
+        response = client.delete(f"/v1/templates/{template_id}")
+        return response
+
+    @classmethod
+    def health_check(
+        cls,
+        *,
+        base_url: str = "https://api.hopx.dev",
+    ) -> Dict[str, Any]:
+        """
+        Check API health status.
+
+        This endpoint does not require authentication and can be used to verify
+        API availability and connectivity.
+
+        Args:
+            base_url: API base URL (default: production)
+
+        Returns:
+            Dict with health status information
+
+        Example:
+            >>> health = Sandbox.health_check()
+            >>> print(health)  # {'status': 'ok', ...}
+
+            >>> # Check custom/staging API
+            >>> health = Sandbox.health_check(base_url="https://staging-api.hopx.dev")
+        """
+        # Use a minimal client without API key for health check
+        import httpx
+        try:
+            response = httpx.get(f"{base_url.rstrip('/')}/health", timeout=10)
+            response.raise_for_status()
+            return response.json()
+        except httpx.HTTPError as e:
+            from .errors import NetworkError
+            raise NetworkError(f"Health check failed: {e}")
+
     # =============================================================================
     # INSTANCE METHODS (for managing individual sandbox)
     # =============================================================================
@@ -848,22 +918,24 @@ class Sandbox:
     def get_info(self) -> SandboxInfo:
         """
         Get current sandbox information.
-        
+
         Returns:
             SandboxInfo with current state
-        
+
         Raises:
             NotFoundError: Sandbox not found
-        
+
         Example:
             >>> sandbox = Sandbox.create(template="nodejs")
             >>> info = sandbox.get_info()
             >>> print(f"Status: {info.status}")
             >>> print(f"URL: {info.public_host}")
-            >>> print(f"Ends at: {info.end_at}")
+            >>> print(f"Internet access: {info.internet_access}")
+            >>> if info.expires_at:
+            ...     print(f"Expires at: {info.expires_at}")
         """
         response = self._client.get(f"/v1/sandboxes/{self.sandbox_id}")
-        
+
         # Parse resources if present
         resources = None
         if response.get("resources"):
@@ -873,29 +945,96 @@ class Sandbox:
                 memory_mb=response["resources"]["memory_mb"],
                 disk_mb=response["resources"]["disk_mb"]
             )
-        
+
+        # Parse timestamps
+        created_at = None
+        if response.get("created_at"):
+            try:
+                from datetime import datetime
+                created_at = datetime.fromisoformat(response["created_at"].replace("Z", "+00:00"))
+            except (ValueError, AttributeError):
+                pass
+
+        expires_at = None
+        if response.get("expires_at"):
+            try:
+                from datetime import datetime
+                expires_at = datetime.fromisoformat(response["expires_at"].replace("Z", "+00:00"))
+            except (ValueError, AttributeError):
+                pass
+
         return SandboxInfo(
             sandbox_id=response["id"],
             template_id=response.get("template_id"),
             template_name=response.get("template_name"),
-            organization_id=response.get("organization_id", ""),
+            organization_id=response.get("organization_id", 0),
             node_id=response.get("node_id"),
             region=response.get("region"),
             status=response["status"],
             public_host=response.get("public_host") or response.get("direct_url", ""),
+            direct_url=response.get("direct_url"),
+            preview_url=response.get("preview_url"),
             resources=resources,
-            created_at=response.get("created_at"),
-            started_at=None,  # TODO: Add when API provides it
-            end_at=None,  # TODO: Add when API provides it
+            internet_access=response.get("internet_access"),
+            live_mode=response.get("live_mode"),
+            timeout_seconds=response.get("timeout_seconds"),
+            expires_at=expires_at,
+            created_at=created_at,
+            # Legacy fields for backward compatibility
+            started_at=None,
+            end_at=expires_at,  # Map expires_at to end_at for backward compat
         )
     
+    def get_agent_info(self) -> Dict[str, Any]:
+        """
+        Get VM agent information.
+
+        Returns comprehensive information about the VM agent including version,
+        OS, architecture, available endpoints, and supported features.
+
+        Returns:
+            Dict with agent information:
+            - agent: Agent name (e.g., "hopx-vm-agent-desktop")
+            - agent_version: Agent version (e.g., "3.2.8")
+            - vm_id: VM identifier
+            - os: Operating system
+            - arch: Architecture (e.g., "amd64", "arm64")
+            - go_version: Go version used to build agent
+            - vm_ip: VM IP address
+            - vm_port: VM port
+            - start_time: Agent start timestamp
+            - uptime: Uptime in seconds
+            - endpoints: Map of available endpoints
+            - features: Available features dict
+
+        Example:
+            >>> info = sandbox.get_agent_info()
+            >>> print(f"Agent: {info['agent']} v{info['agent_version']}")
+            >>> print(f"OS: {info['os']} ({info['arch']})")
+            >>> print(f"Uptime: {info['uptime']}s")
+            >>> print(f"Features: {list(info['features'].keys())}")
+
+        Note:
+            Requires Agent v3.1.0+. GET /info endpoint.
+        """
+        self._ensure_agent_client()
+
+        logger.debug("Getting agent info")
+
+        response = self._agent_client.get(
+            "/info",
+            operation="get agent info"
+        )
+
+        return response.json()
+
     def get_agent_metrics(self) -> Dict[str, Any]:
         """
         Get real-time agent metrics.
-        
+
         Returns agent performance and health metrics including uptime,
         request counts, error counts, and performance statistics.
-        
+
         Returns:
             Dict with metrics including:
             - uptime_seconds: Agent uptime
@@ -903,27 +1042,95 @@ class Sandbox:
             - total_errors: Total errors count
             - requests_total: Per-endpoint request counts
             - avg_duration_ms: Average request duration by endpoint
-        
+
         Example:
             >>> metrics = sandbox.get_agent_metrics()
             >>> print(f"Uptime: {metrics['uptime_seconds']}s")
             >>> print(f"Total requests: {metrics.get('total_requests', 0)}")
             >>> print(f"Errors: {metrics.get('total_errors', 0)}")
-        
+
         Note:
-            Requires Agent v3.1.0+
+            Requires Agent v3.1.0+. GET /metrics/snapshot endpoint.
         """
         self._ensure_agent_client()
-        
+
         logger.debug("Getting agent metrics")
-        
+
         response = self._agent_client.get(
             "/metrics/snapshot",
             operation="get agent metrics"
         )
-        
+
         return response.json()
-    
+
+    def list_system_processes(self) -> List[Dict[str, Any]]:
+        """
+        List all running system processes in the sandbox.
+
+        Returns a list of all processes running in the VM, not just background
+        code executions. Useful for debugging and monitoring system state.
+
+        Returns:
+            List of dicts with process information:
+            - pid: Process ID
+            - name: Process name
+            - status: Process status
+            - cpu_percent: CPU usage percentage
+            - memory_mb: Memory usage in MB
+            - command: Full command line
+
+        Example:
+            >>> processes = sandbox.list_system_processes()
+            >>> for proc in processes:
+            ...     print(f"{proc['pid']}: {proc['name']} (CPU: {proc.get('cpu_percent', 0)}%)")
+
+        Note:
+            Requires Agent v3.2.0+. GET /processes endpoint.
+        """
+        self._ensure_agent_client()
+
+        logger.debug("Listing system processes")
+
+        response = self._agent_client.get(
+            "/processes",
+            operation="list system processes"
+        )
+
+        return response.json().get("processes", [])
+
+    def get_jupyter_sessions(self) -> List[Dict[str, Any]]:
+        """
+        Get Jupyter kernel session status.
+
+        Returns information about active Jupyter kernel sessions, useful for
+        debugging kernel state and managing long-running Python executions.
+
+        Returns:
+            List of active Jupyter sessions with:
+            - kernel_id: Kernel identifier
+            - execution_state: idle, busy, starting
+            - connections: Number of connections
+            - last_activity: Last activity timestamp
+
+        Example:
+            >>> sessions = sandbox.get_jupyter_sessions()
+            >>> for session in sessions:
+            ...     print(f"Kernel {session['kernel_id']}: {session['execution_state']}")
+
+        Note:
+            Requires Agent v3.2.0+ with Jupyter support. GET /jupyter/sessions endpoint.
+        """
+        self._ensure_agent_client()
+
+        logger.debug("Getting Jupyter sessions")
+
+        response = self._agent_client.get(
+            "/jupyter/sessions",
+            operation="get jupyter sessions"
+        )
+
+        return response.json().get("sessions", [])
+
     def run_code(
         self,
         code: str,
